@@ -7,6 +7,7 @@ import typer
 
 # first party
 from dbtc import dbtCloudClient as dbtc
+from dbtc.console import console
 
 app = typer.Typer()
 
@@ -106,7 +107,7 @@ def _dbt_api_request(ctx: typer.Context, property: str, method: str, *args, **kw
     instance = dbtc(**ctx.obj)
     api = getattr(instance, property)
     data = getattr(api, method)(*args, **kwargs)
-    typer.echo(json.dumps(data))
+    console.print_json(json.dumps(data))
 
 
 def _dbt_cloud_request(ctx: typer.Context, method: str, *args, **kwargs):
@@ -470,6 +471,33 @@ def get_model(
     _dbt_metadata_request(ctx, 'get_model', job_id, unique_id, run_id=run_id)
 
 
+@app.command()
+def get_model_by_environment(
+    ctx: typer.Context,
+    environment_id: int = ENVIRONMENT_ID,
+    unique_id: str = UNIQUE_ID,
+    last_run_count: int = typer.Option(
+        10,
+        '--last-run-count',
+        help='Number of run results where this model was built to return (max of 10)',
+    ),
+    with_catalog: bool = typer.Option(
+        False,
+        '--with-catalog',
+        help='If true, return only runs that have catalog information for this model',
+    ),
+):
+    """Query information about a particular model based on environment_id."""
+    _dbt_metadata_request(
+        ctx,
+        'get_model_by_environment',
+        environment_id,
+        unique_id,
+        last_run_count=last_run_count,
+        with_catalog=with_catalog,
+    )
+
+
 @app.command()
 def get_models(
     ctx: typer.Context,
@@ -946,6 +974,26 @@ def trigger_job(
     account_id: int = ACCOUNT_ID,
     job_id: int = JOB_ID,
     payload: str = PAYLOAD,
+    should_poll: bool = typer.Option(
+        True,
+        help='Poll until job completion (status is one of success, failure, or '
+        'cancelled)',
+    ),
+    poll_interval: int = typer.Option(
+        10, '--poll-interval', help='Number of seconds to wait in between polling.'
+    ),
+    restart_from_failure: bool = typer.Option(
+        False, help='Restart your job from the point of failure'
+    ),
+    trigger_on_failure_only: bool = typer.Option(
+        False,
+        help=(
+            'Only relevant when setting restart_from_failure to True.  This has the '
+            'effect of only triggering the job when the prior invocation was not '
+            'successful. Otherwise, the function will exit prior to triggering the '
+            'job.'
+        ),
+    ),
 ):
     """Trigger job to run."""
     _dbt_cloud_request(
@@ -954,27 +1002,10 @@ def trigger_job(
         account_id,
         job_id,
         json.loads(payload),
-    )
-
-
-@app.command()
-def trigger_job_and_poll(
-    ctx: typer.Context,
-    account_id: int = ACCOUNT_ID,
-    job_id: int = JOB_ID,
-    payload: str = PAYLOAD,
-    poll_interval: int = typer.Option(
-        10, '--poll-interval', help='Number of seconds to wait in between polling.'
-    ),
-):
-    """Trigger job and poll until completion (success or failure)."""
-    _dbt_cloud_request(
-        ctx,
-        'trigger_job_and_poll',
-        account_id,
-        job_id,
-        json.loads(payload),
+        should_poll=should_poll,
         poll_interval=poll_interval,
+        restart_from_failure=restart_from_failure,
+        trigger_on_failure_only=trigger_on_failure_only,
     )
 
 
